==> gamification-services-1.0.0-RC01-sources.jar: org/exoplatform/addons/gamification/listener/forum/GamificationForumListener.java <==
package org.exoplatform.addons.gamification.listener.forum;

import org.exoplatform.addons.gamification.entities.domain.effective.GamificationActionsHistory;
import org.exoplatform.addons.gamification.listener.GamificationListener;
import org.exoplatform.addons.gamification.service.configuration.RuleService;
import org.exoplatform.addons.gamification.service.dto.configuration.RuleDTO;
import org.exoplatform.addons.gamification.service.effective.GamificationProcessor;
import org.exoplatform.addons.gamification.service.effective.GamificationService;
import org.exoplatform.forum.service.*;
import org.exoplatform.services.listener.Asynchronous;
import org.exoplatform.services.log.ExoLogger;
import org.exoplatform.services.log.Log;
import org.exoplatform.social.core.identity.provider.OrganizationIdentityProvider;
import org.exoplatform.social.core.manager.ActivityManager;
import org.exoplatform.social.core.manager.IdentityManager;
import org.exoplatform.social.core.space.spi.SpaceService;

import java.beans.PropertyChangeEvent;
import java.util.List;

@Asynchronous
public class GamificationForumListener extends ForumEventListener implements GamificationListener {

    private static final Log LOG = ExoLogger.getLogger(GamificationForumListener.class);

    protected RuleService ruleService;
    protected GamificationProcessor gamificationProcessor;
    protected IdentityManager identityManager;
    protected SpaceService spaceService;
    protected GamificationService gamificationService;
    protected ActivityManager activityManager;
    protected ForumService forumService;

    public GamificationForumListener(RuleService ruleService, GamificationProcessor gamificationProcessor, IdentityManager identityManager
                                    , SpaceService spaceService, GamificationService gamificationService, ActivityManager activityManager, ForumService forumService) {
        this.ruleService = ruleService;
        this.gamificationProcessor = gamificationProcessor;
        this.identityManager = identityManager;
        this.spaceService = spaceService;
        this.gamificationService = gamificationService;
        this.activityManager = activityManager;
        this.forumService = forumService;
    }

    @Override
    public void saveCategory(Category category) {
    }

    @Override
    public void saveForum(Forum forum) {
    }

    @Override
    public void addPost(Post post) {

        /**
        // Compute Activity
        String activityId = forumService.getActivityIdForOwnerId(post.getTopicId());

        //
        if (Utils.isEmpty(activityId)) {
            ExoSocialActivity forumPostActivity = activityManager.getActivity(activityId);

            //
            if (forumPostActivity == null) {

            }

        }
         */

        GamificationActionsHistory aHistory = null;

        // To hold GamificationRule
        RuleDTO ruleDto = null;

        // Get associated rule : Reward user who send a relationship request
        ruleDto = ruleService.findEnableRuleByTitle(GAMIFICATION_FORUM_ADD_POST);

        // Process only when an enable rule is found
        if (ruleDto != null) {
            try {
                aHistory = build(ruleDto,identityManager.getOrCreateIdentity(OrganizationIdentityProvider.NAME, post.getOwner(), false).getId());

                // Save Gamification Context
                gamificationProcessor.execute(aHistory);
            } catch (Exception e) {
                LOG.error("Error to process gamification for Rule {}", ruleDto.getTitle(), e);
            }
        }

    }


    @Override
    public void updatePost(Post post) {


    }

    @Override
    public void updatePost(Post post, int type) {

    }

    @Override
    public void addTopic(Topic topic) {

        GamificationActionsHistory aHistory = null;

        // To hold GamificationRule
        RuleDTO ruleDto = null;

        // Get associated rule : Reward user who send a relationship request
        ruleDto = ruleService.findEnableRuleByTitle(GAMIFICATION_FORUM_ADD_TOPIC);

        // Process only when an enable rule is found
        if (ruleDto != null) {
            try {
                aHistory = build(ruleDto, identityManager.getOrCreateIdentity(OrganizationIdentityProvider.NAME, topic.getOwner(), false).getId());

                gamificationProcessor.execute(aHistory);

            } catch (Exception e) {
                LOG.error("Error to process gamification for Rule {}", ruleDto.getTitle(), e);
            }
        }

    }

    @Override
    public void updateTopic(Topic topic) {

        PropertyChangeEvent[] events = topic.getChangeEvent();

        for (int i = 0; i < events.length; i++) {
            processUpdateTopicType(events[i], topic);
        }


    }

    @Override
    public void updateTopics(List<Topic> topics, boolean isLock) {

    }


    @Override
    public void moveTopic(Topic topic, String toCategoryName, String toForumName) {

    }


    @Override
    public void mergeTopic(Topic newTopic, String removeActivityId1, String removeActivityId2) {

    }

    @Override
    public void splitTopic(Topic newTopic, Topic splitedTopic, String removeActivityId) {

    }

    @Override
    public void removeActivity(String activityId) {

    }

    @Override
    public void removeComment(String activityId, String commentId) {

    }

    @Override
    public void movePost(List<Post> list, List<String> list1, String s) {

    }

    private void processUpdateTopicType(PropertyChangeEvent event, Topic topic) {

        // Start gamification process only when a topic is voted
        if (Topic.TOPIC_RATING.equals(event.getPropertyName())) {

            GamificationActionsHistory aHistory = null;

            // To hold GamificationRule
            RuleDTO ruleDto = null;

            // Get associated rule : Reward user who send a relationship request
            ruleDto = ruleService.findEnableRuleByTitle(GAMIFICATION_FORUM_VOTE_TOPIC);

            // Process only when an enable rule is found
            if (ruleDto != null) {
                try {
                    aHistory = build(ruleDto,identityManager.getOrCreateIdentity(OrganizationIdentityProvider.NAME, topic.getOwner(), false).getId());

                    // Save Gamification Context
                    gamificationProcessor.execute(aHistory);

                } catch (Exception e) {
                    LOG.error("Error to process gamification for Rule {}", ruleDto.getTitle(), e);
                }
            }

        }

    }
}

==> gamification-services-1.2.3-RC01-sources.jar: org/exoplatform/addons/gamification/listener/forum/GamificationForumListener.java <==
package org.exoplatform.addons.gamification.listener.forum;

import static org.exoplatform.addons.gamification.GamificationConstant.*;

import java.beans.PropertyChangeEvent;
import java.util.List;

import org.exoplatform.addons.gamification.service.configuration.RuleService;
import org.exoplatform.addons.gamification.service.effective.GamificationService;
import org.exoplatform.forum.service.*;
import org.exoplatform.services.listener.Asynchronous;
import org.exoplatform.services.log.ExoLogger;
import org.exoplatform.services.log.Log;
import org.exoplatform.social.core.identity.provider.OrganizationIdentityProvider;
import org.exoplatform.social.core.manager.ActivityManager;
import org.exoplatform.social.core.manager.IdentityManager;
import org.exoplatform.social.core.space.spi.SpaceService;

@Asynchronous
public class GamificationForumListener extends ForumEventListener {

    private static final Log LOG = ExoLogger.getLogger(GamificationForumListener.class);

    protected RuleService ruleService;
    protected IdentityManager identityManager;
    protected SpaceService spaceService;
    protected GamificationService gamificationService;
    protected ActivityManager activityManager;
    protected ForumService forumService;

    public GamificationForumListener(RuleService ruleService, IdentityManager identityManager
            , SpaceService spaceService, GamificationService gamificationService, ActivityManager activityManager, ForumService forumService) {
        this.ruleService = ruleService;
        this.identityManager = identityManager;
        this.spaceService = spaceService;
        this.gamificationService = gamificationService;
        this.activityManager = activityManager;
        this.forumService = forumService;
    }

    @Override
    public void saveCategory(Category category) {
    }

    @Override
    public void saveForum(Forum forum) {
    }

    @Override
    public void addPost(Post post) {

        String actorId = identityManager.getOrCreateIdentity(OrganizationIdentityProvider.NAME, post.getOwner(), false).getId();
        gamificationService.createHistory(GAMIFICATION_FORUM_ADD_POST,actorId,actorId,ForumUtils.createdSubForumLink(post.toString(),post.getTopicId(),true));

    }
    @Override
    public void updatePost(Post post) {
    }

    @Override
    public void updatePost(Post post, int type) {

    }

    @Override
    public void addTopic(Topic topic) {

        String actorId = identityManager.getOrCreateIdentity(OrganizationIdentityProvider.NAME, topic.getOwner(), false).getId();
        gamificationService.createHistory(GAMIFICATION_FORUM_ADD_TOPIC,actorId, actorId,ForumUtils.createdSubForumLink(topic.toString(),topic.getId(),true));

    }

    @Override
    public void updateTopic(Topic topic) {

        PropertyChangeEvent[] events = topic.getChangeEvent();

        for (int i = 0; i < events.length; i++) {
            processUpdateTopicType(events[i], topic);
        }


    }

    @Override
    public void updateTopics(List<Topic> topics, boolean isLock) {

    }


    @Override
    public void moveTopic(Topic topic, String toCategoryName, String toForumName) {

    }


    @Override
    public void mergeTopic(Topic newTopic, String removeActivityId1, String removeActivityId2) {

    }

    @Override
    public void splitTopic(Topic newTopic, Topic splitedTopic, String removeActivityId) {

    }

    @Override
    public void removeActivity(String activityId) {

    }

    @Override
    public void removeComment(String activityId, String commentId) {

    }

    @Override
    public void movePost(List<Post> list, List<String> list1, String s) {

    }

    @Override
    public void openTopic(String userId, String topicId) {

    }

    private void processUpdateTopicType(PropertyChangeEvent event, Topic topic) {

        // Start gamification process only when a topic is voted
        if (Topic.TOPIC_RATING.equals(event.getPropertyName())) {
            String actorId = identityManager.getOrCreateIdentity(OrganizationIdentityProvider.NAME, topic.getOwner(), false).getId();
            gamificationService.createHistory(GAMIFICATION_FORUM_VOTE_TOPIC,actorId,actorId,ForumUtils.createdSubForumLink(topic.toString(), topic.getId(), true));
        }

    }
}
